Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1108)

Unified Diff: Source/core/paint/DeprecatedPaintLayer.cpp

Issue 1092673002: Move FilterEffectRenderer to core/paint/ (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Rebase. Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/paint/DeprecatedPaintLayer.h ('k') | Source/core/paint/DeprecatedPaintLayerFilterInfo.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/paint/DeprecatedPaintLayer.cpp
diff --git a/Source/core/paint/DeprecatedPaintLayer.cpp b/Source/core/paint/DeprecatedPaintLayer.cpp
index 772739645eafaab5818506242571916a4eb51c94..e1d9bc4864943ad3ccecd6146362164b0a87b738 100644
--- a/Source/core/paint/DeprecatedPaintLayer.cpp
+++ b/Source/core/paint/DeprecatedPaintLayer.cpp
@@ -54,7 +54,6 @@
#include "core/frame/LocalFrame.h"
#include "core/html/HTMLFrameElement.h"
#include "core/layout/ColumnInfo.h"
-#include "core/layout/FilterEffectRenderer.h"
#include "core/layout/HitTestRequest.h"
#include "core/layout/HitTestResult.h"
#include "core/layout/HitTestingTransformState.h"
@@ -73,6 +72,7 @@
#include "core/layout/svg/ReferenceFilterBuilder.h"
#include "core/page/Page.h"
#include "core/page/scrolling/ScrollingCoordinator.h"
+#include "core/paint/FilterEffectBuilder.h"
#include "platform/LengthFunctions.h"
#include "platform/RuntimeEnabledFeatures.h"
#include "platform/TraceEvent.h"
@@ -2552,7 +2552,7 @@ void DeprecatedPaintLayer::ensureCompositedDeprecatedPaintLayerMapping()
m_compositedDeprecatedPaintLayerMapping = adoptPtr(new CompositedDeprecatedPaintLayerMapping(*this));
m_compositedDeprecatedPaintLayerMapping->setNeedsGraphicsLayerUpdate(GraphicsLayerUpdateSubtree);
- updateOrRemoveFilterEffectRenderer();
+ updateOrRemoveFilterEffectBuilder();
}
void DeprecatedPaintLayer::clearCompositedDeprecatedPaintLayerMapping(bool layerBeingDestroyed)
@@ -2569,7 +2569,7 @@ void DeprecatedPaintLayer::clearCompositedDeprecatedPaintLayerMapping(bool layer
m_compositedDeprecatedPaintLayerMapping.clear();
if (!layerBeingDestroyed)
- updateOrRemoveFilterEffectRenderer();
+ updateOrRemoveFilterEffectBuilder();
}
void DeprecatedPaintLayer::setGroupedMapping(CompositedDeprecatedPaintLayerMapping* groupedMapping, bool layerBeingDestroyed)
@@ -2722,7 +2722,7 @@ void DeprecatedPaintLayer::updateFilters(const ComputedStyle* oldStyle, const Co
return;
updateOrRemoveFilterClients();
- updateOrRemoveFilterEffectRenderer();
+ updateOrRemoveFilterEffectBuilder();
}
bool DeprecatedPaintLayer::attemptDirectCompositingUpdate(StyleDifference diff, const ComputedStyle* oldStyle)
@@ -2858,30 +2858,28 @@ void DeprecatedPaintLayer::updateOrRemoveFilterClients()
filterInfo()->removeReferenceFilterClients();
}
-void DeprecatedPaintLayer::updateOrRemoveFilterEffectRenderer()
+void DeprecatedPaintLayer::updateOrRemoveFilterEffectBuilder()
{
// FilterEffectRenderer is only used to render the filters in software mode,
// so we always need to run updateOrRemoveFilterEffectRenderer after the composited
// mode might have changed for this layer.
if (!paintsWithFilters()) {
// Don't delete the whole filter info here, because we might use it
// for loading CSS shader files.
if (DeprecatedPaintLayerFilterInfo* filterInfo = this->filterInfo())
- filterInfo->setRenderer(nullptr);
+ filterInfo->setBuilder(nullptr);
return;
}
DeprecatedPaintLayerFilterInfo* filterInfo = ensureFilterInfo();
- if (!filterInfo->renderer()) {
- RefPtrWillBeRawPtr<FilterEffectRenderer> filterRenderer = FilterEffectRenderer::create();
- filterInfo->setRenderer(filterRenderer.release());
- }
+ if (!filterInfo->builder())
+ filterInfo->setBuilder(FilterEffectBuilder::create());
// If the filter fails to build, remove it from the layer. It will still attempt to
// go through regular processing (e.g. compositing), but never apply anything.
- if (!filterInfo->renderer()->build(layoutObject(), computeFilterOperations(layoutObject()->styleRef())))
- filterInfo->setRenderer(nullptr);
+ if (!filterInfo->builder()->build(layoutObject(), computeFilterOperations(layoutObject()->styleRef())))
+ filterInfo->setBuilder(nullptr);
}
void DeprecatedPaintLayer::filterNeedsPaintInvalidation()
« no previous file with comments | « Source/core/paint/DeprecatedPaintLayer.h ('k') | Source/core/paint/DeprecatedPaintLayerFilterInfo.h » ('j') | no next file with comments »
@@ -2858,30 +2858,28 @@ void DeprecatedPaintLayer::updateOrRemoveFilterClients()
{
- // FilterEffectRenderer is only used to render the filters in software mode,
- // so we always need to run updateOrRemoveFilterEffectRenderer after the composited
+ // FilterEffectBuilder is only used to render the filters in software mode,
+ // so we always need to run updateOrRemoveFilterEffectBuilder after the composited
// mode might have changed for this layer.
if (!paintsWithFilters()) {

Powered by Google App Engine
This is Rietveld 408576698